## 钻石铲安装方法

钻石铲目前能够通过pip方式下载,请参阅[pip方式安装](#pip方式安装)

其他的操作系统请自行下载源码编译, 请参阅[源码使用](#源码使用)


##### pip方式安装

在root终端中使用`pip install diamond-shovel`下载钻石铲, 并通过`diamond-shovel -I`完成安装

在后续的使用中可以直接使用`diamond-shovel`命令调用钻石铲

##### 源码使用

请使用以下命令将仓库clone到本地, 或通过[Release](https://github.com/diamond-shovel/diamond-shovel/releases)页面下载源码压缩包:

```bash
git clone https://github.com/diamond-shovel/diamond-shovel.git
```

并直接调用`wrapped_main.py`即可
